@@ -2,6 +2,7 @@ package JSON::Validator;
 use Mojo::Base -base;
 use Exporter 'import';
 use JSON::Validator::Error;
+use Mojo::File 'path';
 use Mojo::JSON;
 use Mojo::JSON::Pointer;
 use Mojo::URL;
@@ -17,7 +18,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.90';
+our $VERSION = '0.91';
 our @EXPORT_OK = 'validate_json';
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -137,7 +138,7 @@ sub _load_schema {
     warn "[JSON::Validator] Loading schema $url namespace=$namespace scheme=$scheme\n"
       if DEBUG;
     $doc
-      = $scheme eq 'file' ? Mojo::Util::slurp($namespace)
+      = $scheme eq 'file' ? path($namespace)->slurp
       : $scheme eq 'data' ? $self->_load_schema_from_data($url, $namespace)
       :                     $self->_load_schema_from_url($url, $namespace);
     $self->_register_document($self->_load_schema_from_text($doc), $namespace);
@@ -173,7 +174,7 @@ sub _load_schema_from_url {
     my $path = File::Spec->catfile($_, $cache_file);
     next unless -r $path;
     warn "[JSON::Validator] Loading cached file $path\n" if DEBUG;
-    return Mojo::Util::slurp($path);
+    return path($path)->slurp;
   }
 
   $tx = $self->ua->get($url);
@@ -784,7 +785,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.90
+0.91
 
 =head1 SYNOPSIS
 
@@ -1140,4 +1141,8 @@ the terms of the Artistic License version 2.0.
 
 Jan Henning Thorsen - C<jhthorsen@cpan.org>
 
+Daniel Böhmer - C<post@daniel-boehmer.de>
+
+Martin Renvoize - C<martin.renvoize@gmail.com>
+
 =cut
